==> camel-k-model-v1-5.3.0-sources.jar: annotations/io/fabric8/camelk/v1/ConfigurationSpecFluent.java <==
package io.fabric8.camelk.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ConfigurationSpecFluent<A extends ConfigurationSpecFluent<A>> extends Fluent<A> {


    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
    public String getValue();
    public A withValue(String value);
    public Boolean hasValue();
    public A withNewValue(StringBuilder arg1);
    public A withNewValue(int[] arg1,int arg2,int arg3);
    public A withNewValue(char[] arg1);
    public A withNewValue(StringBuffer arg1);
    public A withNewValue(byte[] arg1,int arg2);
    public A withNewValue(byte[] arg1);
    public A withNewValue(char[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewValue(String arg1);
}

==> camel-k-model-v1-5.3.1-sources.jar: annotations/io/fabric8/camelk/v1/ConfigurationSpecFluent.java <==
package io.fabric8.camelk.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ConfigurationSpecFluent<A extends ConfigurationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
    public String getValue();
    public A withValue(String value);
    public Boolean hasValue();
    public A withNewValue(StringBuilder arg1);
    public A withNewValue(int[] arg1,int arg2,int arg3);
    public A withNewValue(char[] arg1);
    public A withNewValue(StringBuffer arg1);
    public A withNewValue(byte[] arg1,int arg2);
    public A withNewValue(byte[] arg1);
    public A withNewValue(char[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewValue(String arg1);
}
